@@ -1,15 +1,9 @@
 package App::RetroPAN;
 # vim:ts=4:shiftwidth=4:expandtab
 
-use strict;
-use warnings;
-use utf8;
-
-=encoding utf8
-
 =head1 NAME
 
-App::RetroPAN - Makes a historic minicpan ⏳
+App::RetroPAN - Makes a historic minicpan E<9203>
 
 =head1 SYNOPSIS
 
@@ -17,31 +11,18 @@ App::RetroPAN - Makes a historic minicpan ⏳
 
   my ($author, $dist_name, $url) = find_module_on_date("2011-01-01T00:00:00", "Moose");
 
-  my @dependencies = find_deps_on_date_with_perl("2011-01-01T00:00:00", $], "Moose", "Mouse", "Moo", ...);
-
-  my @dependencies = find_modules_dependencies($author, $dist_name, $]);
-
 =head1 DESCRIPTION
 
 Uses the MetaCPAN API to find releases made prior to a given date to
 satisfy your modules' dependencies.
 
-=head2 Core modules
-
-Newer versions of modules existing in core are currently ignored. This may be
-desirable as users may be reluctant to upgrade core modules from CPAN.
-
 =head1 SEE ALSO
 
 =over
 
-=item *
+=item L<retropan>
 
-L<retropan>
-
-=item *
-
-L<OrePAN2>
+=item L<OrePAN2>
 
 =back
 
@@ -55,23 +36,24 @@ Dave Lambley <dlambley@cpan.org>
 
 =cut
 
+use strict;
+use warnings;
+
 use HTTP::Request;
 use LWP::UserAgent;
-use List::MoreUtils qw/ uniq /;
+use List::Util qw/ uniq /;
 use Module::CoreList;
 use OrePAN2::Injector;
 use OrePAN2::Indexer;
 
 use Cpanel::JSON::XS qw/ encode_json decode_json /;
 
-our $VERSION = '0.03_01';
+our $VERSION = 0.01;
 
 my $ua = LWP::UserAgent->new( keep_alive => 2, agent => "retropan/$VERSION" );
 
 sub find_module_dependencies {
-    my ($au, $dist, $perl_version) = @_;
-
-    $perl_version ||= $];
+    my ($au, $dist) = @_;
 
     my $q = {
         "size" => 1,
@@ -109,18 +91,16 @@ sub find_module_dependencies {
     }
 
     my @deps =
-        grep { !Module::CoreList::is_core($_, undef, $perl_version) }
+        grep { !Module::CoreList::is_core($_) }
         grep { $_ ne "perl" }
         map { $_->{module} } @{ $hit->{_source}->{dependency} };
 
     return @deps;
 }
-
 sub find_module_on_date {
-    my ($module, $before, $perl_version) = @_;
+    my ($module, $before) = @_;
 
-    $perl_version ||= $];
-    return if Module::CoreList::is_core($module, undef, $perl_version);
+    return if Module::CoreList::is_core($module);
 
     # We prefer authorized modules, but can fall back to unauthorized if none
     # available.
@@ -173,7 +153,6 @@ sub find_module_on_date {
     # We therefore iterate through all modules returned to find the newest
     # version.
     foreach my $hit (@{ $data->{hits}->{hits} }) {
-	next if $hit->{_source}->{distribution} eq 'perl';
         foreach my $mod (@{ $hit->{_source}->{module} }) {
             if (($authorized ? $mod->{authorized} : 1) && $mod->{name} eq $module && $mod->{version_numified} > $version) {
                 $author     = $hit->{_source}->{author};
@@ -196,11 +175,6 @@ sub find_module_on_date {
 
 sub find_deps_on_date {
     my ($before, @modules) = @_;
-    return find_deps_on_date_with_perl($before, $], @modules);
-}
-
-sub find_deps_on_date_with_perl {
-    my ($before, $perl_version, @modules) = @_;
 
     my %done_modules;
     my @dists_required;
@@ -210,12 +184,12 @@ sub find_deps_on_date_with_perl {
         my $mod = pop @modules;
         next if $done_modules{$mod};
 
-        my ($au, $dist, $url) = find_module_on_date($mod, $before, $perl_version);
+        my ($au, $dist, $url) = find_module_on_date($mod, $before);
         $done_modules{$mod} = 1;
         next if !defined($au) || !defined($dist);
         $dist_to_url{"$au/$dist"} = $url;
 
-        push @modules, find_module_dependencies($au, $dist, $perl_version);
+        push @modules, find_module_dependencies($au, $dist);
         unshift @dists_required, "$au/$dist";
     }
 
